# neadva
Python 3 implementation of Hungarian Tax Office (NAV) version 3 reporting api
-----------
Alpha version of the module. Can be used to supply data and return transaction numbers safely. More work required for full transfer support of NAV API.

Clone the repo to install:

`git clone https://github.com/andrew-azarov/neadva`

or install using pip:

`pip install neadva`

Warning:
-----------
Tested only with test interface of NAV. Not production interface. Might still have some bugs due to differences in test and prod environment which happens sometimes

Modules required:
-----------
`pip install pycryptodome`